import { CloseDisclosure, EyeIcon, OpenDisclosure } from "@/components/Icons";
import { Disclosure } from "@headlessui/react";
import React, { useState } from "react";

export const PurchaseTab = () => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(0);
  const tabs = [
    { name: "Transaction Status", current: true },
    { name: "Asset Details", current: false },
    { name: "Timeline of Activities", current: false },
    { name: "Escrow Account Information", current: false },
    { name: "Progress Tracking", current: false },
  ];
  return (
    <>
      <span className="text-lg text-prussianBlue/40 mb-4 block">Tracking</span>
      <div className="custom-shadow rounded flex flex-col gap-2">
        <Disclosure as="div" className={`disclosure`} defaultOpen={true}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Purchase Tracker
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="p-8 xl:py-20">
                <div className="xl:h-[10px] xl:bg-gray relative rounded-full">
                  <div
                    className="flex xl:absolute flex-wrap xl:flex-nowrap gap-4 -top-4  xl:justify-center xl:px-7 w-full"
                    aria-label="Tabs"
                  >
                    {tabs.map((tab, i) => (
                      <div
                        onClick={() => setSelectedTabIdx(i)}
                        key={tab.name}
                        className={`
                        ${
                          i === selectedTabIdx
                            ? "bg-reefGold text-white xl:bg-transparent xl:text-black"
                            : i < selectedTabIdx
                            ? "bg-reefGold text-white xl:bg-transparent xl:text-black"
                            : ""
                        }
                        text-sm flex flex-col items-center cursor-pointer custom-shadow xl:shadow-none px-4 py-2 rounded-full font-medium text-center`}
                      >
                        <button
                          onClick={() => setSelectedTabIdx(i)}
                          className={`
                          ${
                            i === selectedTabIdx
                              ? "!border-reefGold"
                              : i < selectedTabIdx
                              ? "!border-reefGold"
                              : ""
                          } h-[26px] border-gray w-[26px] rounded-full border-[6px] cursor-pointer xl:flex justify-center items-center hidden `}
                        >
                          <span className="bg-white h-[14px] w-[14px] rounded-full"></span>
                        </button>
                        {tab.name}
                      </div>
                    ))}
                  </div>
                </div>

                {selectedTabIdx === 0 && (
                  <div className="mt-20">
                    <h3 className="font-medium text-lg mb-3">
                      Transaction Status
                    </h3>
                    <div className="overflow-x-auto custom-shadow rounded">
                      <table className="custom-shadow rounded w-[700px]">
                        <thead>
                          <tr className="shadow">
                            <th className="px-10 py-3 font-normal text-start">
                              Transaction Title
                            </th>
                            <th className="px-10 py-3 font-normal text-start">
                              Created
                            </th>
                            <th className="px-10 py-3 font-normal text-start">
                              Amount
                            </th>
                          </tr>
                        </thead>
                        <tbody>
                          <tr>
                            <td className="px-10 py-3 text-start">
                              Fund Verification in Progress
                            </td>
                            <td className="px-10 py-3 text-start">NBD Bank</td>
                            <td className="px-10 py-3 text-start">
                              USD 2000000{" "}
                            </td>
                          </tr>
                        </tbody>
                      </table>
                    </div>
                  </div>
                )}
                {selectedTabIdx === 1 && (
                  <div className="mt-20">
                    <h3 className="font-medium text-lg mb-3">Asset Details</h3>
                    <div className="overflow-x-auto custom-shadow rounded">
                      <table className="custom-shadow rounded w-[800px]">
                        <thead>
                          <tr className="shadow">
                            <th className="p-3 text-sm font-normal text-start">
                              Category
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Name
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Value
                            </th>
                            <th className="p-3 text-sm font-normal text-start whitespace-nowrap">
                              Evaluation certificate
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Description
                            </th>
                          </tr>
                        </thead>
                        <tbody>
                          <tr>
                            <td className="p-3 text-sm text-start">Cars</td>
                            <td className="p-3 text-sm text-start">
                              Mercedes-Benz Car
                            </td>
                            <td className="p-3 text-sm text-start">
                              USD 50000{" "}
                            </td>
                            <td className="p-3 text-sm text-start">
                              <span className="flex items-center gap-5">
                                Yes <EyeIcon />
                              </span>{" "}
                            </td>
                            <td className="p-3 text-start text-xs">
                              Mercedes Benz G65, Model 2024 6500 KM mileage{" "}
                            </td>
                          </tr>
                        </tbody>
                      </table>
                    </div>
                  </div>
                )}
                {selectedTabIdx === 2 && (
                  <div className="mt-20">
                    <h3 className="font-medium text-lg mb-3">
                      Timeline Of Activities
                    </h3>
                    <div className="overflow-x-auto custom-shadow rounded">
                      <table className="custom-shadow rounded w-[800px]">
                        <thead>
                          <tr className="shadow">
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Name
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Type
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              View Activities
                            </th>
                          </tr>
                        </thead>
                        <tbody>
                          <tr>
                            <td className="p-3 text-sm text-start">
                              Asset Ref: 123876
                            </td>
                            <td className="p-3 text-sm text-start">
                              Mercedes-Benz Car
                            </td>
                            <td className="p-3 text-sm text-start">
                              <button>
                                <EyeIcon />{" "}
                              </button>{" "}
                            </td>
                          </tr>
                        </tbody>
                      </table>
                    </div>
                  </div>
                )}
                {selectedTabIdx === 3 && (
                  <div className="mt-20">
                    <h3 className="font-medium text-lg mb-3">
                      Escrow Account Information
                    </h3>
                    <div className="overflow-x-auto custom-shadow rounded">
                      <table className="custom-shadow rounded w-[800px]">
                        <thead>
                          <tr className="shadow">
                            <th className="p-3 text-sm font-normal text-start">
                              Asset{" "}
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Description
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Bank Name
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Applied date
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Status
                            </th>
                          </tr>
                        </thead>
                        <tbody>
                          <tr>
                            <td className="p-3 text-sm text-start">Cars</td>
                            <td className="p-3 text-sm text-start">
                              Mercedes Benz G65, Model 2024 6500 KM mileage{" "}
                            </td>
                            <td className="p-3 text-sm text-start">UBL Bank</td>
                            <td className="p-3 text-sm text-start">
                              22/04/2024
                            </td>
                            <td className="p-3 text-sm text-start">Approve</td>
                          </tr>
                        </tbody>
                      </table>
                    </div>
                  </div>
                )}
                {selectedTabIdx === 4 && (
                  <div className="mt-20">
                    <h3 className="font-medium text-lg mb-3">
                      Progress Tracking
                    </h3>
                    <div className="overflow-x-auto custom-shadow rounded">
                      <table className="custom-shadow rounded w-[800px]">
                        <thead>
                          <tr className="shadow">
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Type{" "}
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Asset Name
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Value
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Applied date
                            </th>
                            <th className="p-3 text-sm font-normal text-start">
                              Status
                            </th>
                          </tr>
                        </thead>
                        <tbody>
                          <tr>
                            <td className="p-3 text-sm text-start">Cars</td>
                            <td className="p-3 text-sm text-start">
                              Mercedes-Benz Car
                            </td>
                            <td className="p-3 text-sm text-start">
                              USD 50000{" "}
                            </td>
                            <td className="p-3 text-sm text-start">
                              22/04/2024
                            </td>
                            <td className="p-3 text-sm text-start">Approve</td>
                          </tr>
                        </tbody>
                      </table>
                    </div>
                  </div>
                )}
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
      </div>
    </>
  );
};
